@@ -1,11 +1,10 @@
-
-from lazyTest.file import GetElementSource
-from lazyTest.utils import Sleep, ClearTestResult, createData,cls_Sleep
+from lazyTest.file import GetElementSource,ReadIni,ReadCsvFileToList
+from lazyTest.utils import Sleep, clearLogAndReport, createData,cls_Sleep
 from lazyTest.case import TestCase
 from lazyTest.base import  WebOption
 from lazyTest.page import Page
 
-__version__ = '2.0.3'
+__version__ = '2.0.4'
 
 
 __author__ = 'buxiubuzhi'
@@ -15,10 +14,12 @@ __description__ = "WebUI自动化测试框架"
 __all__ = [
     "Sleep",
     "Page",
-    "ClearTestResult",
+    "clearLogAndReport",
     "WebOption",
     "createData",
     "TestCase",
     "cls_Sleep",
-    "GetElementSource"
+    "GetElementSource",
+    "ReadIni",
+    "ReadCsvFileToList"
 ]
