@@ -1,6 +1,8 @@
 # -*- coding = UTF-8 -*-
-# Author   :buxiubuzhi
-# time     :2020/2/13  14:44
+# Author   : buxiubuzhi
+# Project  : lazyTest
+# FileName : base.py
+# Describe :
 # ---------------------------------------
 import functools
 
@@ -19,21 +21,21 @@ def _retrying(func):
         ele = iter(args[1])  # 非字符串，创建迭代器
 
         # 实现重试机制，报错就会重试，直到迭代所有
-        def run(ele,*args):
-            args = list(args)       # 兼容多个参数
+        def run(ele, *args):
+            args = list(args)  # 兼容多个参数
             try:
                 e = next(ele)
             except StopIteration:
                 return
             try:
-                args[1] = e         # 处理时只处理第一个参数
+                args[1] = e  # 处理时只处理第一个参数
                 result = func(*args)
                 return result
             except BaseException as e:  # 捕获所有异常
-                result = run(ele,*args)
+                result = run(ele, *args)
             return result
 
-        result = run(ele,*args)
+        result = run(ele, *args)
         return result
 
     return inner
@@ -111,13 +113,33 @@ class WebOption(Config):
             return text_list
 
     @_retrying
-    def GetElements(self, selector: str, index: int = None) -> list:
+    def GetElements(self, selector: str, text: str = "",index: int = None,):
         """获取一组元素"""
+        eles = []
         ele = self.locate_elements(selector)
-        if index is not None:
-            return ele[index]
-        else:
-            return ele
+        if text != "":
+            for i in ele:
+                if i.text == text:
+                    eles.append(i)
+            if index is not None:
+                return eles[index]
+            return eles
+        return ele
+
+    @_retrying
+    def ElementFilterByText(self, selector: str, text: str):
+        """获取一组元素，根据指定的文本进行过滤"""
+        ele = self.locate_elements(selector)
+        if text is not None:
+            for i in ele:
+                if i.text == text:
+                    return i
+
+    @_retrying
+    def ElementFilterByIndex(self, selector: str, index: int = None):
+        """获取一组元素，根据指定的索引进行过滤"""
+        ele = self.locate_elements(selector)
+        return ele[index]
 
     @_retrying
     def GetAttribute(self, selector: str, value: str = 'value') -> str:
