@@ -1,6 +1,8 @@
 # -*- coding = UTF-8 -*-
-# Author   :buxiubuzhi
-# time     :2020/2/13  14:44
+# Author   : buxiubuzhi
+# Project  : lazyTest
+# FileName : template.py
+# Describe :
 # ---------------------------------------
 
 
@@ -8,10 +10,10 @@
 CONFTEST = """
 
 # -*- coding = UTF-8 -*-
-# Author   :
-# File     : conftest.py
-# time     : 
-# Describe :
+# Author   : buxiubuzhi
+# Project  : lazyTest
+# FileName : conftest.py
+# Describe : 
 # ---------------------------------------
 import os
 import sys
@@ -117,6 +119,7 @@ def pytest_runtest_setup(item):
 """
 # pytest.ini文件模板
 PYTEST = """
+注意： 该文件不可存在中文描述，实际运行时需要将所有的注释删除
 [pytest]
 # 控制台输出日志配置
 log_cli = true
@@ -127,28 +130,39 @@ log_date_format = %Y-%M-%D %H:%M:%S
 log_file_level = INFO
 log_file_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
 log_file_date_format = %Y-%M-%D %H:%M:%S
-# 自定义参数
 #---------------------------------------------------
 # 配置浏览器，支持： Chrome、Firefox、Ie、Edge、PhantomJs（无头浏览器）、ChromeOptions（谷歌提供无头）、h5（支持iPhone X）
 Terminal = Chrome
 # 填写需要访问页面的url，此处不需要指定路由，路由在pages层指定
-URL = http://buxiubuzhi:7799
+URL = http://localhost:8080
 # 截图存放路径，可修改，截图文件名在conftest.py文件中定义
 filepath = /result/screenshot/
+# 元素文件的路径
+elementPath = /resources/element/   
+# 元素文件类型（目前只支持yaml文件）    
+suffix = .yaml                          
 # 日志存放路径，可修改
 logpath = /result/log/log.log
 # 自定义登录参数，可根据conftest.py文件中定义的添加，如果需要其他参数，需要先在conftest.py文件中定义
 username = 
 password = 
+#----------------------------------------------------
+
 """
 # main.py文件模板
 MAIN = """
+# -*- coding = UTF-8 -*-
+# Author   : buxiubuzhi
+# Project  : lazyTest
+# FileName : main.py
+# Describe : 
+# ---------------------------------------
+
 import os
 import sys
-import time
 
 sys.path.append(os.path.dirname(os.path.dirname(__file__)))
-from lazyTest import ClearTestResult
+from lazyTest import clearLogAndReport
 
 
 def getPorjectPath():
@@ -158,42 +172,37 @@ def getPorjectPath():
     return os.path.dirname(os.path.dirname(__file__))
 
 
-def clearLogAndReport():
-    print("----------清空上次测试结果----------")
-    path = getPorjectPath() + "/result"
-    ClearTestResult(path)
-    time.sleep(2)
-    print("----------测试结果清空成功----------")
-
-
 def runlastFailed():
-    print("启动失败用例重跑")
-    cmd = "pytest -s --lf {}/case --alluredir {}/result/report".format(getPorjectPath(), getPorjectPath())
+    print("-------------启动失败用例重跑-------------")
+    cmd = f"pytest -s --lf {getPorjectPath()}/case --alluredir {getPorjectPath()}/result/report"
     print(os.system(cmd))
 
 
 def startReport():
     print("-------------启动测试报告--------------")
-    cmd = "allure serve {}/result/report".format(getPorjectPath())
+    cmd = f"allure serve {getPorjectPath()}/result/report"
     print(os.system(cmd))
 
 
-def startCase(cases):
+@clearLogAndReport(getPorjectPath())
+def startCase(cases = ""):
     print("------------开始执行测试------------")
-    cmd = "pytest -s {}/case/{} --alluredir {}/result/report".format(getPorjectPath(), cases, getPorjectPath())
+    cmd = f"pytest -s {getPorjectPath()}/case/{cases} --alluredir {getPorjectPath()}/result/report"
     print(os.system(cmd))
 
 
-def run(cases=" "):
-    clearLogAndReport()
-    startCase(cases)
-    s = input("请选择要启用的服务:1:启动失败用例重跑;\t2：启动测试报告;")
-    if s == "1":
-        runlastFailed()
-        s = input("是否启动测试报告:y/n")
-    if s == "2" or s == "y":
-        startReport()
-run()
+@clearLogAndReport(getPorjectPath())
+def startMarkCase(mark = ""):
+    print("------------根据标签执行用例------------")
+    cmd = f"pytest -s {getPorjectPath()}/case/ -m {mark} --alluredir {getPorjectPath()}/result/report"
+    print(os.system(cmd))
+
+
+if __name__ == '__main__':
+    startCase()         # 执行所有用例
+    startMarkCase()     # 执行标记用例
+    runlastFailed()     # 执行失败用例
+    startReport()       # 启动测试报告
 """
 
 
